<?php

declare(strict_types=1);
/**
 * SPDX-FileCopyrightText: 2018 Nextcloud GmbH and Nextcloud contributors
 * SPDX-License-Identifier: AGPL-3.0-or-later
 */

namespace OCA\Support\BackgroundJobs;

use OCA\Support\Service\SubscriptionService;
use OCP\AppFramework\Utility\ITimeFactory;
use OCP\BackgroundJob\TimedJob;
use OCP\IConfig;

class CheckSubscription extends TimedJob {
	public function __construct(
		ITimeFactory $factory,
		private readonly IConfig $config,
		private readonly SubscriptionService $subscriptionService,
	) {
		parent::__construct($factory);
		// Run every 5 minutes
		$this->setInterval(60 * 5);
	}

	public function run($argument) {
		$lastCheck = $this->config->getAppValue('support', 'last_check', 0);
		// renew subscription info every 23h
		if (time() - $lastCheck > 23 * 60 * 60) {
			$this->subscriptionService->renewSubscriptionInfo(false);
			$this->subscriptionService->checkSubscription();
		}
	}
}
